Index: /FCKeditor.Java/branches/2.4/src/main/java/net/fckeditor/FCKeditor.java
===================================================================
--- /FCKeditor.Java/branches/2.4/src/main/java/net/fckeditor/FCKeditor.java	(revision 1517)
+++ /FCKeditor.Java/branches/2.4/src/main/java/net/fckeditor/FCKeditor.java	(revision 1518)
@@ -63,6 +63,4 @@
 	 * @param toolbarSet
 	 *            toolbarSet name
-	 * @param value
-	 *            initial value
 	 */
 	public FCKeditor(final HttpServletRequest request,
Index: /FCKeditor.Java/branches/2.4/src/main/java/net/fckeditor/ResourceType.java
===================================================================
--- /FCKeditor.Java/branches/2.4/src/main/java/net/fckeditor/ResourceType.java	(revision 1517)
+++ /FCKeditor.Java/branches/2.4/src/main/java/net/fckeditor/ResourceType.java	(revision 1518)
@@ -1,2 +1,22 @@
+/*
+ * FCKeditor - The text editor for Internet - http://www.fckeditor.net
+ * Copyright (C) 2003-2008 Frederico Caldeira Knabben
+ * 
+ * == BEGIN LICENSE ==
+ * 
+ * Licensed under the terms of any of the following licenses at your
+ * choice:
+ * 
+ *  - GNU General Public License Version 2 or later (the "GPL")
+ *    http://www.gnu.org/licenses/gpl.html
+ * 
+ *  - GNU Lesser General Public License Version 2.1 or later (the "LGPL")
+ *    http://www.gnu.org/licenses/lgpl.html
+ * 
+ *  - Mozilla Public License Version 1.1 or later (the "MPL")
+ *    http://www.mozilla.org/MPL/MPL-1.1.html
+ * 
+ * == END LICENSE ==
+ */
 package net.fckeditor;
 
Index: /FCKeditor.Java/branches/2.4/src/main/java/net/fckeditor/SessionData.java
===================================================================
--- /FCKeditor.Java/branches/2.4/src/main/java/net/fckeditor/SessionData.java	(revision 1517)
+++ /FCKeditor.Java/branches/2.4/src/main/java/net/fckeditor/SessionData.java	(revision 1518)
@@ -23,22 +23,27 @@
 import javax.servlet.http.HttpServletRequest;
 
+import net.fckeditor.handlers.ConfigurationHandler;
+
 /**
- * Interface to provide session or request based functionality to FCKeditor.Java. Currently, the
- * implemeted class has to implement the following:
+ * Interface to provide session or request based functionality to
+ * FCKeditor.Java. Currently, the implemeted class has to implement the
+ * following:
  * <ul>
  * <li>{@link #isEnabledForFileBrowsing(HttpServletRequest)}: Enables the user to browse/select
  * file.</li>
  * <li>{@link #isEnabledForFileUpload(HttpServletRequest)}: Enables the user to upload files.</li>
  * <li>{@link #getBaseDir(HttpServletRequest)}: Constructs an user based 'BaseDir'.</li>
  * </ul>
  * {@link #isEnabledForFileBrowsing(HttpServletRequest)} and
- * {@link #isEnabledForFileUpload(HttpServletRequest)} are authentification methodes for different
- * kinds of user actions.<br />
+ * {@link #isEnabledForFileUpload(HttpServletRequest)} are authentification
+ * methodes for different kinds of user actions.<br />
  * <br />
- *  This class is managed by {@link ConfigurationHandler}.<br />
+ * This class is managed by {@link ConfigurationHandler}.<br />
  * <br />
- * <b>Warning for commiters: </b>You have to awake that every change of this interface could break
- * all classes which implemented this interface. Therfore you should change this interface for
- * milestone releases only!
+ * <b>Warning for commiters: </b>You have to awake that every change of this
+ * interface could break all classes which implemented this interface. Therfore
+ * you should change this interface for milestone releases only!
  * 
  * @version $Id$
@@ -50,8 +55,10 @@
 	 * If the implemantation doesn't bother you, just return <code>true</code>.
 	 * 
-	 * @param servletRequest
-	 * @return
+	 * @param request
+	 *            Servlet request from user
+	 * @return <code>true</code> if user can upload to the server else
+	 *         <code>false</code>
 	 */
-	public boolean isEnabledForFileUpload(final HttpServletRequest servletRequest);
+	public boolean isEnabledForFileUpload(final HttpServletRequest request);
 
 	/**
@@ -59,8 +66,10 @@
 	 * If the implemantation doesn't bother you, just return <code>true</code>.
 	 * 
-	 * @param servletRequest
-	 * @return
+	 * @param request
+	 *            Servlet request from user
+	 * @return <code>true</code> if use can browse the server else
+	 *         <code>false</code>
 	 */
-	public boolean isEnabledForFileBrowsing(final HttpServletRequest servletRequest);
+	public boolean isEnabledForFileBrowsing(final HttpServletRequest request);
 
 	/**
@@ -68,12 +77,14 @@
 	 * <b>Important:</b>
 	 * <ul>
-	 * <li> If the implementation returns <code>null</code>, {@link ConfigurationHandler} will
-	 * used the default one! That's usefull, if the implementation doesn't bother you.</li>
-	 * <li>The returned directory string has to start with '/', but has to end without '/'.</li>
+	 * <li> If the implementation returns <code>null</code>,
+	 * {@link ConfigurationHandler} will used the default one! That's useful, if
+	 * the implementation doesn't bother you.</li>
+	 * <li>The returned directory string has to start with '/', but has to end
+	 * without '/'.</li>
 	 * </ul>
 	 * 
-	 * @param servletRequest
-	 * @return <code>null</null> or the 'BaseDir' string for the current user.
+	 * @param request
+	 * @return <code>null</code> or the 'BaseDir' string for the current user.
 	 */
-	public String getBaseDir(final HttpServletRequest servletRequest);
+	public String getUserFilesPath(final HttpServletRequest request);
 }
@@ -23,22 +23,27 @@
  * <ul>
- * <li>{@link #isEnabledForFileBrowsing(HttpServletRequest)}: Enables the user to browse/select
- * file.</li>
- * <li>{@link #isEnabledForFileUpload(HttpServletRequest)}: Enables the user to upload files.</li>
- * <li>{@link #getBaseDir(HttpServletRequest)}: Constructs an user based 'BaseDir'.</li>
+ * <li>{@link #isEnabledForFileBrowsing(HttpServletRequest)}: Enables the user
+ * to browse/select file.</li>
+ * <li>{@link #isEnabledForFileUpload(HttpServletRequest)}: Enables the user
+ * to upload files.</li>
+ * <li>{@link #getUserFilesPath(HttpServletRequest)}: Constructs an user based
+ * 'BaseDir'.</li>
  * </ul>
  * {@link #isEnabledForFileBrowsing(HttpServletRequest)} and
Index: /FCKeditor.Java/branches/2.4/src/main/java/net/fckeditor/handlers/ConfigurationHandler.java
===================================================================
--- /FCKeditor.Java/branches/2.4/src/main/java/net/fckeditor/handlers/ConfigurationHandler.java	(revision 1517)
+++ /FCKeditor.Java/branches/2.4/src/main/java/net/fckeditor/handlers/ConfigurationHandler.java	(revision 1518)
@@ -49,5 +49,5 @@
  * See {@link SessionData} for additional informations. For example, to get a user based base dir,
  * for each request {@link #getUserFilesPath(HttpServletRequest)} is calling. If 'sessionData' is set,
  * {@link SessionData#getBaseDir(HttpServletRequest)} will be returned, otherwise the default base
  * dir.
  * 
@@ -96,11 +96,11 @@
 	 * Getter for the base dir (using for user files).
 	 * 
 	 * @return {@link SessionData#getBaseDir(HttpServletRequest)} or the default base dir, if
 	 *         {@link SessionData}} isn't set.
 	 */
 	public static String getUserFilesPath(final HttpServletRequest servletRequest) {
-		if (sessionData == null || sessionData.getBaseDir(servletRequest) == null)
+		if (sessionData == null || sessionData.getUserFilesPath(servletRequest) == null)
 			return getDefaultUserFilesPath();
-		return sessionData.getBaseDir(servletRequest);
+		return sessionData.getUserFilesPath(servletRequest);
 	}
 
@@ -108,5 +108,5 @@
 	 * Getter for the default userFilesPath.
 	 * 
-	 * @return
+	 * @return Default userfiles path (/userfiles)
 	 */
 	public static String getDefaultUserFilesPath() {
@@ -119,5 +119,5 @@
 	 * 
 	 * @param userFilesPath
-	 *            relative to the context root (no leading or ending /).
+	 *            absolute to the context root (e.g. /userfiles)
 	 */
 	public static void setUserFilesPath(final String userFilesPath) {
@@ -164,6 +164,6 @@
 	 *            relative to the context root (no leading or ending /).
 	 */
-	public static void setFckEditorDir(final String fckEditorDir) {
-		ConfigurationHandler.basePath = fckEditorDir;
+	public static void setBasePath(final String basePath) {
+		ConfigurationHandler.basePath = basePath;
 	}
 
@@ -275,16 +275,16 @@
 
 	/**
-	 * Just a wrapper to {@link SessionData.isEnabledForFileUpload(HttpServletRequest)}.
-	 * 
-	 * @param servletRequest
+	 * Just a wrapper to {@link SessionData#isEnabledForFileUpload(HttpServletRequest)}.
+	 * 
+	 * @param request
 	 * @return {@link SessionData#isEnabledForFileUpload(HttpServletRequest)} or false, if
 	 *         sessionData isn't set.
 	 */
-	public static boolean isEnabledForFileUpload(final HttpServletRequest servletRequest) {
-		return (sessionData != null && sessionData.isEnabledForFileUpload(servletRequest));
-	}
-
-	/**
-	 * Just a wrapper to {@link SessionData.isEnabledForFileBrowsing(HttpServletRequest)}.
+	public static boolean isEnabledForFileUpload(final HttpServletRequest request) {
+		return (sessionData != null && sessionData.isEnabledForFileUpload(request));
+	}
+
+	/**
+	 * Just a wrapper to {@link SessionData#isEnabledForFileBrowsing(HttpServletRequest)}.
 	 * 
 	 * @param servletRequest
@@ -49,5 +49,5 @@
  * See {@link SessionData} for additional informations. For example, to get a user based base dir,
  * for each request {@link #getUserFilesPath(HttpServletRequest)} is calling. If 'sessionData' is set,
- * {@link SessionData#getBaseDir(HttpServletRequest)} will be returned, otherwise the default base
+ * {@link SessionData#getUserFilesPath(HttpServletRequest)} will be returned, otherwise the default base
  * dir.
  * 
@@ -96,11 +96,11 @@
 	 * Getter for the base dir (using for user files).
 	 * 
-	 * @return {@link SessionData#getBaseDir(HttpServletRequest)} or the default base dir, if
+	 * @return {@link SessionData#getUserFilesPath(HttpServletRequest)} or the default base dir, if
 	 *         {@link SessionData}} isn't set.
 	 */
